#!/bin/bash
##################################################################
# Licensed Materials - Property of IBM
# 5724-W78
# (C) Copyright IBM Corp. 2010
# All Rights Reserved
# US Government Users Restricted Rights - Use, duplication or
# disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
##################################################################

#
# Name: configureMaxProperties.sh
#
# Changes maximo system properties and end point configurations.
# Sets the values directly in the database to change these
# elements.
# This is one of the two scripts invoked by the user or
# by the launchpad. All steps write log files to the
# Tivoli Service Automation Manager logs directory, which is
# /opt/IBM/tsam/logs by default.
# All variables are read from the script setupEnv.sh.
# Check setupEnv.sh for a list of variables to be changed.
##################################################################

workDir=`dirname "$0"`
SCRIPT_NAME=$0

if [[ "$workDir" =~ ^/ ]]
then
	export TSAM_CONFIG_HOME=$workDir
else
	export TSAM_CONFIG_HOME="$(pwd)"/"${workDir}"
fi

. "$workDir/setupEnv.sh"

# Enable Localization
. "$workDir/../tools/i18n.sh" configureTSAM

# Set the Progress File
export PROGRESS_FILE=$TSAM_POSTINSTALL_PROGRESS_1

echo ""

# The first parameter is the scriptname without the ending .sh
function callStep
{
	CURRENT_STEP_ID=$1
	shift;
	CURRENT_STEP=$1
	shift;
	CURRENT_SCRIPTNAME=${CURRENT_STEP}.sh

	LOGFILE_NAME_PREFIX=${CURRENT_STEP_ID}_${CURRENT_STEP}_${TIMESTAMP}

	if ! test -f "$PROGRESS_FILE" || ! cat "$PROGRESS_FILE" | egrep "^$CURRENT_STEP_ID$" 1>/dev/null 2>/dev/null
	then
		# invoke the command
		"$workDir/${CURRENT_SCRIPTNAME}" $@ 1>>${TSAM_LOG}/${LOGFILE_NAME_PREFIX}.log 2>>${TSAM_LOG}/${LOGFILE_NAME_PREFIX}.err
		RC=$?
		# write rc to stdout
		echo "RC="$RC >>${TSAM_LOG}/${LOGFILE_NAME_PREFIX}.log
		
		if ! [[ "$RC" == "0" ]]
		then
			printLocalizedMessage errorMessage
			echo ${TSAM_LOG}/${LOGFILE_NAME_PREFIX}.log
			echo ${TSAM_LOG}/${LOGFILE_NAME_PREFIX}.err
			echo ""
			printLocalizedMessage logTitle
			echo ${TSAM_LOG}/${LOGFILE_NAME_PREFIX}.log:
			tail -n 10 "${TSAM_LOG}/${LOGFILE_NAME_PREFIX}.log"
			echo ""
			echo ${TSAM_LOG}/${LOGFILE_NAME_PREFIX}.err:
			tail -n 10 "${TSAM_LOG}/${LOGFILE_NAME_PREFIX}.err"

			# write rc to stderr
			echo "RC="$RC >>${TSAM_LOG}/${LOGFILE_NAME_PREFIX}.err
		
			echo ""
			printLocalizedMessage fixAndRestart
			printLocalizedMessage pressEnterToContinue
			read

			exit $RC
		fi
		echo $CURRENT_STEP_ID >> "$PROGRESS_FILE"
	fi
}

function unittest
{
	if test -f "$workDir"/$(basename "$SCRIPT_NAME") && ! printLocalizedMessage a | grep "^[*][*][*]" 1>/dev/null 2>/dev/null
	then
		exit 0
	else
		exit 1
	fi
}

if [[ "$1" == "--test" ]]
then
	unittest
fi

printLocalizedMessage logDestination

mkdir -p $TSAM_LOG

if test -f "$PROGRESS_FILE"
then
	echo ""
	printLocalizedMessage warningNotClean_1
	echo ""
	printLocalizedMessage warningNotClean_2
	echo ""
	printLocalizedMessage warningNotClean_3
	echo ""
	printLocalizedMessage warningNotClean_4
	read KEY
	if [ "$KEY" == "1" ] || [ "$KEY" == "2" ]
	then
		# if 1 is selected, continue with next step after last attempt
		# if 2 is selected, restart from beginning
		if [[ "$KEY" == "2" ]]
		then
			printLocalizedMessage postInstallRestartLabel
			rm -f "$PROGRESS_FILE"
		fi	
	else 
		# otherwise exit immediately
		exit 4
	fi	
fi

echo ""

printLocalizedMessage middlewareCheckLabel
callStep 100_CHECKMIDDLEWARE checkMiddleware

printLocalizedMessage maximoPropertiesSetLabel
callStep 101_SETMAXIMOPROPERTY setMaximoProperty mail.smtp.host "$MAIL_SMTP_HOST"
callStep 102_SETMAXIMOPROPERTY setMaximoProperty mxe.hostname "$MXE_HOSTNAME"
callStep 103_SETMAXIMOPROPERTY setMaximoProperty mxe.adminEmail "$MXE_ADMINEMAIL"
callStep 104_SETMAXIMOPROPERTY setMaximoProperty mxe.int.webappurl "$MXE_INT_WEBAPPURL"
callStep 105_SETMAXIMOPROPERTY setMaximoProperty LDAP.AdminPassword "$LDAP_ADMIN_PW" PASSWORD
callStep 106_SETMAXIMOPROPERTY setMaximoProperty LDAP.ServerHostName "$LDAP_SERVER"
callStep 107_SETMAXIMOPROPERTY setMaximoProperty LDAP.ServerPort "$LDAP_PORT"
callStep 108_SETMAXIMOPROPERTY setMaximoProperty LDAP.AdminDN "$LDAP_ADMIN_FULL"

printLocalizedMessage endpointPropertiesSetLabel
callStep 110_SETENDPOINTCONFIG setEndPointConfig PMRDPRBC URL "https://$MXE_HOSTNAME:$MXServer_MAXIMO_PORT/cloud/rest/projects"
callStep 111_SETENDPOINTCONFIG setEndPointConfig PMRDPRBC USERNAME "$MAXADMIN"
callStep 112_SETENDPOINTCONFIG setEndPointConfig PMRDPRBC PASSWORD "$MAXADMIN_PW"
callStep 113_SETENDPOINTCONFIG setEndPointConfig PMZHBWSCR USERNAME "$SSH_USER_NAME"
callStep 114_SETENDPOINTCONFIG setEndPointConfig PMZHBWSCR PASSWORD "$SSH_PASSWORD"

printLocalizedMessage stopWASLabel
callStep 120_STOPWAS stopWAS
printLocalizedMessage startWASLabel
callStep 121_STARTWAS startWAS

printLocalizedMessage pressEnterToContinue
read
