#!/bin/bash
##################################################################
# Licensed Materials - Property of IBM
# 5724-W78
# (C) Copyright IBM Corp. 2010
# All Rights Reserved
# US Government Users Restricted Rights - Use, duplication or
# disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
##################################################################

#
# Name: configureTSAM.sh
# 
# This file is directly called by the user or by the launchpad.
# If one of the steps failed and the user restarts the 
# script after repairing the error, he is asked if he wants to
# proceed on the step which failed, or if he wants to start
# from the beginning. The script also stores log files
# into the Tivoli Service Automation Manager logs file directory
# which is /opt/IBM/tsam/logs by default
# for each step performed. If something failed, the user
# sees the name of the log files linked to the failed step
# and also the last ten lines of these log files.
# All variables are read from the script setupEnv.sh. Check setupEnv.sh
# for a list of variables to be changed if you want to call this script
# without the launchpad.
# The i18n is done by the script i18n.sh.
##################################################################

workDir=`dirname "$0"`
SCRIPT_NAME=$0

if [[ "$workDir" =~ ^/ ]]
then
	export TSAM_CONFIG_HOME=$workDir
else
	export TSAM_CONFIG_HOME="$(pwd)"/"${workDir}"
fi

. "$workDir/setupEnv.sh"

# Enable Localization
. "$workDir/../tools/i18n.sh" configureTSAM

# Set the Progress File
export PROGRESS_FILE=$TSAM_POSTINSTALL_PROGRESS_2

echo ""

# The first parameter is the stepname, the second parameter is the scriptname without the ending .sh
function callStep
{
	CURRENT_STEP_ID=$1
	CURRENT_STEP=$2
	CURRENT_SCRIPTNAME=${CURRENT_STEP}.sh

	LOGFILE_NAME_PREFIX=${CURRENT_STEP_ID}_${CURRENT_STEP}_${TIMESTAMP}

	if ! test -f "$PROGRESS_FILE" || ! cat "$PROGRESS_FILE" | egrep "^$CURRENT_STEP_ID$" 1>/dev/null 2>/dev/null
	then
		# invoke the command
		"$workDir/${CURRENT_SCRIPTNAME}" 1>>${TSAM_LOG}/${LOGFILE_NAME_PREFIX}.log 2>>${TSAM_LOG}/${LOGFILE_NAME_PREFIX}.err
		RC=$?
		# write rc to stdout
		echo "RC="$RC >>${TSAM_LOG}/${LOGFILE_NAME_PREFIX}.log
		
		if ! [[ "$RC" == "0" ]]
		then
			printLocalizedMessage errorMessage
			echo ${TSAM_LOG}/${LOGFILE_NAME_PREFIX}.log
			echo ${TSAM_LOG}/${LOGFILE_NAME_PREFIX}.err
			echo
			printLocalizedMessage logTitle
			echo ${TSAM_LOG}/${LOGFILE_NAME_PREFIX}.log:
			tail -n 10 "${TSAM_LOG}/${LOGFILE_NAME_PREFIX}.log"
			echo ""
			echo ${TSAM_LOG}/${LOGFILE_NAME_PREFIX}.err:
			tail -n 10 "${TSAM_LOG}/${LOGFILE_NAME_PREFIX}.err"

			# write rc to stderr
			echo "RC="$RC >>${TSAM_LOG}/${LOGFILE_NAME_PREFIX}.err
		
			echo ""
			printLocalizedMessage fixAndRestart
			printLocalizedMessage pressEnterToContinue
			read

			exit $RC
		fi
		echo $CURRENT_STEP_ID >> "$PROGRESS_FILE"
	fi
}

function unittest
{
	if test -f "$workDir"/$(basename "$SCRIPT_NAME") && ! printLocalizedMessage a | grep "^[*][*][*]" 1>/dev/null 2>/dev/null
	then
		exit 0
	else
		exit 1
	fi
}

if [[ "$1" == "--test" ]]
then
	unittest
fi

printLocalizedMessage logDestination

mkdir -p $TSAM_LOG

if test -f "$PROGRESS_FILE"
then
	echo ""
	printLocalizedMessage warningNotClean_1
	echo ""
	printLocalizedMessage warningNotClean_2
	echo ""
	printLocalizedMessage warningNotClean_3
	echo ""
	printLocalizedMessage warningNotClean_4
	read KEY
	if [ "$KEY" == "1" ] || [ "$KEY" == "2" ]
	then
		# if 1 is selected, continue with next step after last attempt
		# if 2 is selected, restart from beginning
		if [[ "$KEY" == "2" ]]
		then
			printLocalizedMessage postInstallRestartLabel
			rm -f "$PROGRESS_FILE"
		fi	
	else 
		# otherwise exit immediately
		exit 4
	fi	
fi

echo ""

printLocalizedMessage middlewareCheckLabel
callStep 201_CHECK_MIDDLEWARE checkMiddleware

printLocalizedMessage stepTSAMcomponentsLabel
callStep 202_CHANGE_APPLICATION_CLASSLOADER changeApplClassLoaderOrderToPARENT
callStep 203_CHANGE_APPLICATION_WAR_CLASSLOADER changeApplWARClassLoaderPolicyToSINGLE
callStep 204_ENABLE_CLASSLOADER_RELOAD enableApplClassReloading

printLocalizedMessage stopWASLabel
callStep 205_STOP_RESTART_WAS stopWAS
printLocalizedMessage startWASLabel
callStep 206_START_RESTART_WAS startWAS

printLocalizedMessage stepCreateDB
callStep 207_CREATE_CLOUD_MGMT createCloudManagementSubsystemDB

printLocalizedMessage stepWASRelationship
callStep 208_ESTABLISH_TRUST_REL establishTrustRelationshipForTSAM

printLocalizedMessage stepWASConfigTPM
callStep 209_CREATE_JDBCPROVIDER createJDBCProvider
callStep 210_CREATE_DATASOURCE createDataSource
callStep 211_CREATE_TIMERMANAGER createTimerManager
callStep 212_CREATE_GLOBALVARIABLE_TIOHOME createGlobalVariableTIO_HOME
callStep 213_DISABLE_LDAP_CACHE disableLDAPCaches
callStep 214_SYNC_NODE syncNode
callStep 215_STOP_APPLICATION_CDS stopApplicationCDS
callStep 216_DISABLE_CDS_AUTOSTART disableAutoStartForApplicationCDS

printLocalizedMessage stopWASLabel
callStep 217_SSHKEY_STOP_WAS stopWAS

printLocalizedMessage stepSSHUpdate
callStep 218_SSHKEY_CONFIG configureSSHkey

# from now on, always start TIO completely
printLocalizedMessage startTIOLabel
callStep 219_SSHKEY_START_TIO startTIO

printLocalizedMessage stepTPMCredentials
callStep 220_INSERT_CREDENTIALS_TIO insert_tioCredentials
callStep 221_INSERT_CREDENTIALS_SSHSERVER_MASTER update_sshServerMasterCredentials
callStep 222_INSERT_CREDENTIALS_SSHCLIENT_MASTER update_sshClientMasterCredentials
callStep 223_INSERT_CREDENTIALS_SSHCLIENT_RSA insert_sshClientRSACredentials
callStep 224_INSERT_CREDENTIALS_SSHCLIENT insert_sshClientCredentials
callStep 225_INSERT_CREDENTIALS_SCPCLIENT_RSA insert_scpClientRSACredentials
callStep 226_INSERT_CREDENTIALS_SCPCLIENT insert_scpClientCredentials

printLocalizedMessage startDiscoveryWorkflow
callStep 227_STOP_APPLICATION_CLOUD stopApplicationCloudEAR
callStep 228_STOP_APPLICATION_MAXIMO stopApplicationMAXIMO
callStep 229_START_APPLICATION_MAXIMO startApplicationMAXIMO
callStep 230_START_APPLICATION_CLOUD startApplicationCloudEAR
callStep 231_START_DISCOVERY_WORKFLOW startTPMDiscoveryWorkflow

printLocalizedMessage stepRemoveHypervisorPermDB
callStep 232_HYPERVISOR_MANAGER_PERMISSION_REMOVE removeManageHyperVisorPermission

printLocalizedMessage stepWASPlugin
callStep 233_GENERATE_IHSPLUGIN generateIHSPlugin

printLocalizedMessage stepFilePermission
callStep 234_SET_FILE_PERMISSIONS setFilePermissions

printLocalizedMessage pressEnterToContinue
read
