#!/bin/bash
##################################################################
# Licensed Materials - Property of IBM
# 5724-W78
# (C) Copyright IBM Corp. 2010
# All Rights Reserved
# US Government Users Restricted Rights - Use, duplication or
# disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
##################################################################

#
# Name: validateInstallationParameters.sh
workDir=`dirname "$0"`
SCRIPT_NAME=$0

if [[ "$workDir" =~ ^/ ]]
then
	export TSAM_CONFIG_HOME=$workDir
else
	export TSAM_CONFIG_HOME="$(pwd)"/"${workDir}"
fi

. "$workDir/setupEnv.sh"

# Enable Localization
. "$workDir/../tools/i18n.sh" validateInstallationParameters


RC=0

echo ""

function checkIfUserExists
{
	printLocalizedMessage VerifyUser
	echo $1
	grep $1 /etc/passwd 1>/dev/null 2>&1
	if [[ "$?" == "0" ]]
	then
		printLocalizedMessage UserVerified
		echo "$1 OK" >>$LOGFILE_NAME
	else
		printLocalizedMessage UserNotVerified
		RC=1
		echo "$1" >>$LOGFILE_NAME
	fi
	echo ""
}

function isPortActive
{
	printLocalizedMessage VerifyServer
	SERVER=$1
	PORT=$2
	echo ${SERVER}:${PORT}
	
	RC=0
	
	LINUX_PARAM='-e c'
	
	if [[ "`uname -s`" == "AIX" ]]
	then
		export TNESC=0143
		LINUX_PARAM=""
	fi

	TELNETOUT=$(LANG=C telnet $LINUX_PARAM $1 $2 << EOF 2>/dev/null
c
quit
EOF
)
	if ! echo $TELNETOUT | grep -i "connection closed" 1>/dev/null 2>/dev/null
	then
		RC=1
		echo ${SERVER}:${PORT} $RC >>$LOGFILE_NAME
	fi
	
	if [[ "$RC" == "0" ]]
	then
		printLocalizedMessage ServerVerified
		echo isPortActive $1:$2 OK >>$LOGFILE_NAME
	else
		printLocalizedMessage ServerNotVerified
		echo isPortActive $1:$2 $RC >>$LOGFILE_NAME
		RC=1
	fi
	echo ""
}

function checkWasCredentials
{
    printLocalizedMessage CheckWasCredentials
    TEMPFILE=/tmp/wascheck.txt
    $WAS_HOME/bin/wsadmin.sh -lang jython -c 'print "testing"' -username $WASADMIN -password $WASADMIN_PW >$TEMPFILE
    grep ADMN0022E $TEMPFILE >/dev/null
    if [ $? -eq 0 ]; then
        printLocalizedMessage WasNotValidated
		echo checkWasCredentials $RC >>$LOGFILE_NAME
		cat $TEMPFILE >>$LOGFILE_NAME
    else
        printLocalizedMessage WasValidated
		echo checkWasCredentials OK >>$LOGFILE_NAME
    fi
    rm -f >$TEMPFILE
	echo ""
}

function checkDb2Connect
{
	printLocalizedMessage CheckConnectDb2
	
	su - $DB2ADMIN -c "db2 connect to $DB2MAXIMODBNAME user $DB2MAXIMOUSER using $DB2MAXIMOPW" 1>>$LOGFILE_NAME 2>/dev/null	
	RC=$?

	if [[ "$RC" == "0" ]]
	then
		printLocalizedMessage Db2Connected
		su - $DB2ADMIN -c "db2 disconnect" 1>/dev/null 2> /dev/null	
		echo checkDb2Connect OK >>$LOGFILE_NAME
	else
		printLocalizedMessage Db2NotConnected
		echo checkDb2Connect $RC >>$LOGFILE_NAME
	fi
	echo ""
}

function checkPropertyEncryptor
{
	printLocalizedMessage CheckEncryptor

	templog=/tmp/encr.log
	temperr=/tmp/encr.err
	VALUE=`"$JAVA_HOME"/bin/java -cp "$MAXIMOEAR/businessobjects.jar:$MAXIMOEAR/lib/db2jcc.jar:$TSAM_CONFIG_HOME/Java:." com.ibm.zhybrid.install.MaximoPropertyEncryptor "$DB2_SERVER" "$DB2_PORT" "$DB2MAXIMOUSER" "$DB2MAXIMOPW" "$DB2MAXIMOSCHEMANAME" "$DB2MAXIMODBNAME" "TESTVALUE" 1>$templog 2>$temperr`
	RC=$?
	
	if [[ $RC == 0 ]]
	then
		printLocalizedMessage EncryptorChecked
		echo "checkPropertyEncryptor OK" >>$LOGFILE_NAME
	else
		export ENCRYPTOR_RC=$RC
		printLocalizedMessage EncryptorFailed
		echo ""
		cat $temperr
		echo checkPropertyEncryptor $RC >>$LOGFILE_NAME
		cat $temperr >>$LOGFILE_NAME
	fi
	rm -f /tmp/$templog
	rm -f /tmp/$temperr
	echo ""
}

function logEnvvar
{
	echo $1=$2 >>$LOGFILE_NAME
}

function logEnvironment
{
	logEnvvar TPM_PROV_SERVERNAME $TPM_PROV_SERVERNAME
	logEnvvar WASRXUSER $WASRXUSER
	logEnvvar TIO_HOME $TIO_HOME
	logEnvvar SSH_USER_NAME $SSH_USER_NAME

	logEnvvar DB2_SERVER $DB2_SERVER
	logEnvvar DB2_PORT $DB2_PORT
	logEnvvar DB2ADMIN $DB2ADMIN
	logEnvvar DB2MAXIMOUSER $DB2MAXIMOUSER
	logEnvvar DB2MAXIMODBNAME $DB2MAXIMODBNAME
	logEnvvar DB2MAXIMOSCHEMANAME $DB2MAXIMOSCHEMANAME

	logEnvvar LDAP_SERVER $LDAP_SERVER
	logEnvvar LDAP_PORT $LDAP_PORT
	logEnvvar LDAP_ADMIN_FULL $LDAP_ADMIN_FULL

	logEnvvar WAS_HOME $WAS_HOME
	logEnvvar WAS_PROFILE_NAME $WAS_PROFILE_NAME
	logEnvvar WAS_CELL_NAME $WAS_CELL_NAME
	logEnvvar WAS_CELLMANAGER_NAME $WAS_CELLMANAGER_NAME
	logEnvvar WAS_NODE_NAME $WAS_NODE_NAME
	logEnvvar WAS_MXSERVER_NAME $WAS_MXSERVER_NAME
	logEnvvar WAS_WEBSERVER_NAME $WAS_WEBSERVER_NAME
	logEnvvar WASADMIN $WASADMIN

	logEnvvar IHS_HOME $IHS_HOME
	logEnvvar IHS_WEBSERVER1_DIR $IHS_WEBSERVER1_DIR

	logEnvvar MAXADMIN $MAXADMIN
	logEnvvar MAIL_SMTP_HOST $MAIL_SMTP_HOST
	logEnvvar MXE_HOSTNAME_FULL $MXE_HOSTNAME_FULL
	echo "" >>$LOGFILE_NAME
}

printLocalizedMessage logDestination

mkdir -p $TSAM_LOG

# Logfile
LOGFILE_NAME=${TSAM_LOG}/000_VALIDATEPARAMETERS_${TIMESTAMP}.log
echo "" >$LOGFILE_NAME
echo $LOGFILE_NAME

logEnvironment

# Check user existences
checkIfUserExists $WASRXUSER
checkIfUserExists $SSH_USER_NAME
checkIfUserExists $DB2ADMIN
checkIfUserExists $DB2MAXIMOUSER

# Check server and port
isPortActive ${DB2_SERVER} ${DB2_PORT}
isPortActive ${LDAP_SERVER} ${LDAP_PORT}
isPortActive ${TPM_PROV_SERVERNAME} ${MXServer_MAXIMO_PORT}

checkWasCredentials

# Check DB2 connect
checkDb2Connect

if [[ $RC == 0 ]]
then
	checkPropertyEncryptor
fi

printLocalizedMessage pressEnterToContinue
read
